@@ -1,7 +1,7 @@
 package App::CompleteUtils;
 
-our $DATE = '2014-12-29'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-06-19'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -22,12 +22,20 @@ App::CompleteUtils - Collection of CLI utilities related to completion and Compl
 
 =head1 VERSION
 
-This document describes version 0.05 of App::CompleteUtils (from Perl distribution App-CompleteUtils), released on 2015-12-29.
+This document describes version 0.06 of App::CompleteUtils (from Perl distribution App-CompleteUtils), released on 2015-06-19.
 
 =head1 SYNOPSIS
 
 This distribution provides several command-line utilities related to
-(shell) completion and the L<Complete> modules family.
+(shell) completion and the L<Complete> modules family:
+
+=over
+
+=item * L<_testcomp>
+
+=item * L<testcomp>
+
+=back
 
 =head1 SEE ALSO
 
@@ -55,7 +63,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
